==> huawei_map-5.3.0%2B301.tar.gz: lib/components/components.dart <==
/*
    Copyright 2020-2021. Huawei Technologies Co., Ltd. All rights reserved.

    Licensed under the Apache License, Version 2.0 (the "License")
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        https://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

export 'bitmapDescriptor.dart';
export 'callbacks.dart';
export 'cameraUpdate.dart';
export 'cameraPosition.dart';
export 'cap.dart';
export 'circleUpdates.dart';
export 'circle.dart';
export 'circleId.dart';
export 'jointType.dart';
export 'latLng.dart';
export 'latLngBounds.dart';
export 'markerUpdates.dart';
export 'marker.dart';
export 'markerId.dart';
export 'infoWindow.dart';
export 'patternItem.dart';
export 'polygonUpdates.dart';
export 'polygon.dart';
export 'polygonId.dart';
export 'polylineUpdates.dart';
export 'polyline.dart';
export 'polylineId.dart';
export 'screenCoordinate.dart';
export 'minMaxZoomPreference.dart';
export 'cameraTargetBounds.dart';
export 'huaweiMapOptions.dart';
export 'pointOfInterest.dart';
export 'location.dart';

export '../utils/circle.dart';
export '../utils/marker.dart';
export '../utils/polygon.dart';
export '../utils/polyline.dart';
export '../constants/mapType.dart';

//Ground Overlay
export 'groundOverlay.dart';
export 'groundOverlayId.dart';
export 'groundOverlayUpdates.dart';
export '../utils/groundOverlay.dart';

//Plugin methods
export '../channel/huaweiMapUtilMethodChannel.dart';

//Tile Overlay
export 'tileOverlay.dart';
export 'tileOverlayId.dart';
export 'tileOverlayUpdates.dart';
export '../utils/tileOverlay.dart';
export 'tileProviders/tile.dart';
export 'tileProviders/urlTile.dart';
export 'tileProviders/repetitiveTile.dart';

//Animation
export 'animations/animation.dart';
export 'animations/alphaAnimation.dart';
export 'animations/rotateAnimation.dart';
export 'animations/scaleAnimation.dart';
export 'animations/translateAnimation.dart';

//Huawei Map Utils
export '../channel/huaweiMapUtilMethodChannel.dart';

==> huawei_map-6.5.0%2B301.tar.gz: lib/components/components.dart <==
/*
    Copyright 2020-2022. Huawei Technologies Co., Ltd. All rights reserved.

    Licensed under the Apache License, Version 2.0 (the "License")
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        https://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

export 'bitmapDescriptor.dart';
export 'callbacks.dart';
export 'cameraUpdate.dart';
export 'cameraPosition.dart';
export 'cap.dart';
export 'circleUpdates.dart';
export 'circle.dart';
export 'circleId.dart';
export 'jointType.dart';
export 'latLng.dart';
export 'latLngBounds.dart';
export 'markerUpdates.dart';
export 'marker.dart';
export 'markerId.dart';
export 'infoWindow.dart';
export 'patternItem.dart';
export 'polygonUpdates.dart';
export 'polygon.dart';
export 'polygonId.dart';
export 'polylineUpdates.dart';
export 'polyline.dart';
export 'polylineId.dart';
export 'screenCoordinate.dart';
export 'minMaxZoomPreference.dart';
export 'cameraTargetBounds.dart';
export 'huaweiMapOptions.dart';
export 'pointOfInterest.dart';
export 'location.dart';

export '../utils/circle.dart';
export '../utils/marker.dart';
export '../utils/polygon.dart';
export '../utils/polyline.dart';
export '../utils/heatMap.dart';
export '../constants/mapType.dart';
export '../constants/radiusUnit.dart';

//Ground Overlay
export 'groundOverlay.dart';
export 'groundOverlayId.dart';
export 'groundOverlayUpdates.dart';
export '../utils/groundOverlay.dart';

//Plugin methods
export '../channel/huaweiMapUtilMethodChannel.dart';
export '../channel/huaweiMapInitializer.dart';

//Tile Overlay
export 'tileOverlay.dart';
export 'tileOverlayId.dart';
export 'tileOverlayUpdates.dart';
export '../utils/tileOverlay.dart';
export 'tileProviders/tile.dart';
export 'tileProviders/urlTile.dart';
export 'tileProviders/repetitiveTile.dart';

//Animation
export 'animations/hmsMarkerAnimation.dart';
export 'animations/alphaAnimation.dart';
export 'animations/rotateAnimation.dart';
export 'animations/scaleAnimation.dart';
export 'animations/translateAnimation.dart';

//Huawei Map Utils
export '../channel/huaweiMapUtilMethodChannel.dart';

//Heat Maps
export 'heatMap.dart';
export 'heatMapId.dart';
export 'heatMapUpdates.dart';
export '../utils/heatMap.dart';
